@@ -59,8 +59,10 @@ def version():
         - 过滤条件fn以`__isnull`结尾时, value自动转换为bool类型        # 2.6.0
         - autoWiki兼容list_fields和retrieve_fields
         - adminclass.MyAjaxAdmin导致和simpleui耦合              # 2.6.1
+        - admin导入导出功能增加对外键的支持                       # 2.6.2
+        - autoWiki模板优化
     """
-    v = "2.6.1"  # 当前: 2.6.1
+    v = "2.6.2"  # 当前: 2.6.2
     return v
 
 
